@@ -27,6 +27,8 @@ sub template {
       INCLUDE_PATH => [$template_root, catdir($template_root, 'include') ],
       INTERPOLATE  => 1,
       ENCODING => 'utf8',
+      START_TAG => quotemeta('{{'),
+      END_TAG   => quotemeta('}}'),
   }) || die "$Template::ERROR\n";
 
   my $vars = {
@@ -51,13 +53,14 @@ sub template {
      return $string;
    }
 
-  $vars->{URL} =~ s"(?<!http:)/+"/"g;
-  $vars->{URL} =~ s"/$""g;
+   $vars->{URL} =~ s"(?<!http:)/+"/"g;
+   $vars->{URL} =~ s"/$""g;
+
+   $vars->{ROOT} =~ s"^http:/+"/"g;
+   $vars->{ROOT} = "/" . $vars->{ROOT} if $vars->{ROOT} !~ m:^/:;
+   $vars->{ROOT} =~ s"/+"/"g;
+   $vars->{ROOT} =~ s"/$""g unless $vars->{ROOT} eq "/";
 
-  $vars->{ROOT} =~ s"^http:/+"/"g;
-  $vars->{ROOT} = "/" . $vars->{ROOT};
-  $vars->{ROOT} =~ s"/+"/"g;
-  $vars->{ROOT} =~ s"/$""g;
 
   my $index = catfile($pensource, 'public', $config->{_default}->{root}, 'index.html');
   $root_index->process('main.tt2', $vars, $index, { binmode => ':utf8' })
